"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _ObjectValue = _interopRequireDefault(require("../object/ObjectValue"));

var _ObjectName = _interopRequireDefault(require("../object/ObjectName"));

var _styles = require("../styles");

var _objectPrototype = require("../utils/objectPrototype");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* intersperse arr with separator */
function intersperse(arr, sep) {
  if (arr.length === 0) {
    return [];
  }

  return arr.slice(1).reduce((xs, x) => xs.concat([sep, x]), [arr[0]]);
}
/**
 * A preview of the object
 */


const ObjectPreview = (_ref) => {
  let data = _ref.data;
  const styles = (0, _styles.useStyles)('ObjectPreview');
  const object = data;

  if (typeof object !== 'object' || object === null || object instanceof Date || object instanceof RegExp) {
    return _react.default.createElement(_ObjectValue.default, {
      object: object
    });
  }

  if (Array.isArray(object)) {
    const maxProperties = styles.arrayMaxProperties;
    const previewArray = object.slice(0, maxProperties).map((element, index) => _react.default.createElement(_ObjectValue.default, {
      key: index,
      object: element
    }));

    if (object.length > maxProperties) {
      previewArray.push(_react.default.createElement("span", {
        key: "ellipsis"
      }, "\u2026"));
    }

    const arrayLength = object.length;
    return _react.default.createElement(_react.default.Fragment, null, _react.default.createElement("span", {
      style: styles.objectDescription
    }, arrayLength === 0 ? `` : `(${arrayLength})\xa0`), _react.default.createElement("span", {
      style: styles.preview
    }, "[", intersperse(previewArray, ', '), "]"));
  } else {
    const maxProperties = styles.objectMaxProperties;
    let propertyNodes = [];

    for (let propertyName in object) {
      const propertyValue = object[propertyName];

      if (_objectPrototype.hasOwnProperty.call(object, propertyName)) {
        let ellipsis;

        if (propertyNodes.length === maxProperties - 1 && Object.keys(object).length > maxProperties) {
          ellipsis = _react.default.createElement("span", {
            key: 'ellipsis'
          }, "\u2026");
        }

        propertyNodes.push(_react.default.createElement("span", {
          key: propertyName
        }, _react.default.createElement(_ObjectName.default, {
          name: propertyName || `""`
        }), ":\xA0", _react.default.createElement(_ObjectValue.default, {
          object: propertyValue
        }), ellipsis));
        if (ellipsis) break;
      }
    }

    const objectConstructorName = object.constructor ? object.constructor.name : 'Object';
    return _react.default.createElement(_react.default.Fragment, null, _react.default.createElement("span", {
      style: styles.objectDescription
    }, objectConstructorName === 'Object' ? '' : `${objectConstructorName} `), _react.default.createElement("span", {
      style: styles.preview
    }, '{', intersperse(propertyNodes, ', '), '}'));
  }
};

var _default = ObjectPreview;
exports.default = _default;